==> net.sf.amateras.air_1.0.0.jar: src/net/sf/amateras/air/mxml/models/ModelProperty.java <==
package net.sf.amateras.air.mxml.models;

import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.PropertyDescriptor;

/**
 * @author Naoki Takezoe
 */
public class ModelProperty {
	private String propertyName;
	//	private AbstractModel model;
	//	private String setterMethod;
	//	private String getterMethod;
	//	private Class type;
	private IPropertyDescriptor descriptor;

	//private Object defaultValue;

	//	public ModelProperty(AbstractModel model, String propertyName, Class type, 
	//			IPropertyDescriptor descriptor){
	//		this(model, propertyName, type, descriptor, "General");
	//	}

	public ModelProperty( String propertyName, 
			PropertyDescriptor descriptor) {
		this( propertyName,  descriptor, null);
	}

	public ModelProperty(String propertyName, 
			PropertyDescriptor descriptor, String category) {
//		this.model = model;
		this.propertyName = propertyName;
		//		this.setterMethod = ReflectionUtil.getSetterName(propertyName);
		//		this.getterMethod = ReflectionUtil.getGetterName(propertyName, false);
//		this.type = type;
		this.descriptor = descriptor;
		//this.defaultValue = defaultValue;
		((PropertyDescriptor) this.descriptor).setCategory(category);
	}

	//	public Object getDefaultValue() {
	//		return defaultValue;
	//	}

	//	public void setProperty(Object value){
	//		try {
	//			Method setter = getSetterMethod();
	//			setter.invoke(model, new Object[]{value});
	//		} catch(Exception ex){
	//			AIRPlugin.logException(ex);
	//		}
	//	}
	//	
	//	public Object getProperty(){
	//		try {
	//			Method getter = getGetterMethod();
	//			return getter.invoke(model, new Object[0]);
	//		} catch(Exception ex){
	//			AIRPlugin.logException(ex);
	//		}
	//		return null;
	//	}
	//	
	//	private Method getSetterMethod() throws Exception {
	//		Class clazz = this.model.getClass();
	//		Method setter = clazz.getMethod(setterMethod, new Class[]{type});
	//		return setter;
	//	}
	//	
	//	private Method getGetterMethod() throws Exception {
	//		Class clazz = this.model.getClass();
	//		Method getter = clazz.getMethod(getterMethod, new Class[]{});
	//		return getter;
	//	}

	public IPropertyDescriptor getDescriptor() {
		return this.descriptor;
	}

	public void setDescriptor(IPropertyDescriptor descriptor) {
		this.descriptor = descriptor;
	}

	public String getPropertyName() {
		return propertyName;
	}

}

==> net.sf.amateras.air_1.0.2.jar: src/net/sf/amateras/air/mxml/models/ModelProperty.java <==
package net.sf.amateras.air.mxml.models;

import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.PropertyDescriptor;

/**
 * @author Naoki Takezoe
 */
public class ModelProperty {
	private String propertyName;
	//	private AbstractModel model;
	//	private String setterMethod;
	//	private String getterMethod;
	//	private Class type;
	private IPropertyDescriptor descriptor;

	//private Object defaultValue;

	//	public ModelProperty(AbstractModel model, String propertyName, Class type, 
	//			IPropertyDescriptor descriptor){
	//		this(model, propertyName, type, descriptor, "General");
	//	}

	public ModelProperty(String propertyName, PropertyDescriptor descriptor) {
		this(propertyName, descriptor, null);
	}

	public ModelProperty(String propertyName, PropertyDescriptor descriptor, String category) {
		//		this.model = model;
		this.propertyName = propertyName;
		//		this.setterMethod = ReflectionUtil.getSetterName(propertyName);
		//		this.getterMethod = ReflectionUtil.getGetterName(propertyName, false);
		//		this.type = type;
		this.descriptor = descriptor;
		//this.defaultValue = defaultValue;
		((PropertyDescriptor) this.descriptor).setCategory(category);
	}

	//	public Object getDefaultValue() {
	//		return defaultValue;
	//	}

	//	public void setProperty(Object value){
	//		try {
	//			Method setter = getSetterMethod();
	//			setter.invoke(model, new Object[]{value});
	//		} catch(Exception ex){
	//			AIRPlugin.logException(ex);
	//		}
	//	}
	//	
	//	public Object getProperty(){
	//		try {
	//			Method getter = getGetterMethod();
	//			return getter.invoke(model, new Object[0]);
	//		} catch(Exception ex){
	//			AIRPlugin.logException(ex);
	//		}
	//		return null;
	//	}
	//	
	//	private Method getSetterMethod() throws Exception {
	//		Class clazz = this.model.getClass();
	//		Method setter = clazz.getMethod(setterMethod, new Class[]{type});
	//		return setter;
	//	}
	//	
	//	private Method getGetterMethod() throws Exception {
	//		Class clazz = this.model.getClass();
	//		Method getter = clazz.getMethod(getterMethod, new Class[]{});
	//		return getter;
	//	}

	public IPropertyDescriptor getDescriptor() {
		return this.descriptor;
	}

	public void setDescriptor(IPropertyDescriptor descriptor) {
		this.descriptor = descriptor;
	}

	public String getPropertyName() {
		return propertyName;
	}

}
